@@ -9,10 +9,12 @@ def cached_property(*args, **kwargs):
 
 
 class PrintTaskStatus:
-    def __init__(self, msg):
+    _active_tasks = []
+
+    def __init__(self, msg, *args, **kwargs):
         self.setup()
         self._done = False
-        self.msg = msg
+        self.msg = msg.format(*args, **kwargs)
 
     @classmethod
     def setup(cls):
@@ -23,26 +25,32 @@ class PrintTaskStatus:
         cls.CLEAR_EOL = curses.tigetstr('el')
         cls._setup = True
 
-    def clear_line(self):
-        sys.stdout.buffer.write(self.BOL + self.CLEAR_EOL)
+    @classmethod
+    def clear_line(cls):
+        sys.stdout.buffer.write(cls.BOL + cls.CLEAR_EOL)
 
     def __enter__(self):
+        PrintTaskStatus._active_tasks.append(self)
         msg = ' {}  {}...'.format(
             click.style('*', fg='yellow', blink=True), self.msg)
         click.echo(msg, nl=False)
         return self
 
     def __exit__(self, type, value, tb):
+        PrintTaskStatus._active_tasks.pop()
         if not self._done:
             self.clear_line()
 
-    def ok(self, msg):
+    def ok(self, msg, *args, **kwargs):
         self.clear_line()
+        msg = msg.format(*args, **kwargs)
         click.echo(' {}  {}'.format(click.style('✓', fg='green'), msg))
         self._done = True
 
-    def fail(self, msg, abort=False):
+    def fail(self, msg, *args, **kwargs):
         self.clear_line()
+        abort = kwargs.pop('abort', False)
+        msg = msg.format(*args, **kwargs)
         if abort:
             msg += ', aborting'
         click.echo(' {}  {}'.format(click.style('✗', fg='red'), msg))
@@ -50,4 +58,25 @@ class PrintTaskStatus:
         if abort:
             sys.exit(1)
 
+    @classmethod
+    def suspend(cls):
+        return SuspendTask(cls._active_tasks)
+
+
+class SuspendTask:
+    def __init__(self, stack):
+        self.stack = stack
+
+    def __enter__(self):
+        if self.stack:
+            task = self.stack[-1]
+            if not task._done:
+                task.clear_line()
+
+    def __exit__(self, type, value, tb):
+        if self.stack:
+            task = self.stack.pop()
+            if not task._done:
+                task.__enter__()
+
 taskstatus = PrintTaskStatus
